<?php
/**
 * A factory class for socket registries
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2012 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class DatabaseWrapperFactory extends ObjectFactory {
	/**
	 * Returns a singleton socket registry instance. If an instance is found in
	 * the registry it will be returned, else a new instance is created and
	 * stored in the same registry entry.
	 *
	 * @return	$wrapperInstance	A database wrapper instance
	 */
	public static final function createWrapperByConfiguredName ($wrapperName) {
		// Get registry instance
		$registryInstance = Registry::getRegistry();

		// Do we have an instance in the registry?
		if ($registryInstance->instanceExists($wrapperName)) {
			// Then use this instance
			$wrapperInstance = $registryInstance->getInstance($wrapperName);
		} else {
			// Get the registry instance
			$wrapperInstance = ObjectFactory::createObjectByConfiguredName($wrapperName);

			// Set the instance in registry for further use
			$registryInstance->addInstance($wrapperName, $wrapperInstance);
		}

		// Return the instance
		return $wrapperInstance;
	}

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}
}

// [EOF]
?>
